pub struct BatchedInstanceBuffer<BD>(pub GpuArrayBuffer<BD>)
where
BD: GpuArrayBufferable + Sync + Send + 'static;Expand description
The GPU buffers holding the data needed to render batches.
For example, in the 3D PBR pipeline this holds MeshUniforms, which are the
BD type parameter in that mode.
Tuple Fields
0: GpuArrayBuffer<BD>Implementations
Sourceimpl<BD> BatchedInstanceBuffer<BD>
impl<BD> BatchedInstanceBuffer<BD>
Sourcepub fn new(limits: &Limits) -> BatchedInstanceBuffer<BD>
pub fn new(limits: &Limits) -> BatchedInstanceBuffer<BD>
Creates a new buffer.
Sourcepub fn instance_data_binding(&self) -> Option<BindingResource<'_>>
pub fn instance_data_binding(&self) -> Option<BindingResource<'_>>
Returns the binding of the buffer that contains the per-instance data.
If we’re in the GPU instance buffer building mode, this buffer needs to be filled in via a compute shader.
Methods from Deref<Target = GpuArrayBuffer<BD>>
pub fn clear(&mut self)
pub fn push(&mut self, value: T) -> GpuArrayBufferIndex<T>
pub fn write_buffer(&mut self, device: &RenderDevice, queue: &RenderQueue)
pub fn binding(&self) -> Option<BindingResource<'_>>